5.0.1 - Released on 2025-12-22
------------------------------
* Re-add compatibility with django 4.

5.0.0 - Released on 2025-12-22
------------------------------
* Update to blacksmith 5
* Drop python 3.9 support

4.0.0 - Released on 2024-11-04
------------------------------
* Update to blacksmith 4
* Drop python 3.8 support
* Replace packaging from poetry to uv / pdm
* Update CI
* Update license to MIT

3.0.0 - Released on 2024-10-14
------------------------------
* Update to blacksmith 3 with nomad sidecar support
* Drop python 3.7

2.0.0 - Released on 2024-10-14
------------------------------
* Update blackmith to version 2.x for python 3.7 compatibility

1.0.1 - Released on 2023-05-10
------------------------------
* Update deps
  * remove aioredis, use redis.asyncio instead (contributor: Michael Vieira)
  * update dev deps

1.0.0 - Released on 2022-02-12
------------------------------
* Update blacksmith to version 1.0
* Add documentation for middleware
* Make the metrics configurable

0.3.0 - Released on 2022-02-07
------------------------------
* Add a setting ``BLACKSMITH_TRANSPORT`` for overriding the transport

0.2.0 - Released on 2022-02-04
------------------------------
* Add the collection parser
* Start the doc


0.1.0 - Released on 22-02-01
----------------------------
* Initial release
